@@ -13,15 +13,28 @@ __all__ = [
 @database_sync_to_async
 def async_search_data(bind, data):
     queryset = bind.get_queryset(data)
-    queryset = bind.filter_queryset(queryset, data)
-    queryset = bind.paginate(queryset, data)
+    filters = data.get('filters', {})
+    if not isinstance(filters, dict):
+        filters = {}
+    queryset = bind.filter_queryset(queryset, filters, data)
+    order = data.get('order', None)
+    if not isinstance(order, (str, bytes, tuple, list)):
+        order = None
+    queryset = bind.order_queryset(queryset, order, data)
+    page = data.get('page', None)
+    if not isinstance(page, (str, int)):
+        page = None
+    limit = data.get('limit', None)
+    if not isinstance(limit, (str, int)):
+        limit = None
+    queryset = bind.paginate(queryset, page, limit, data)
     search_data = bind.serialize_search(queryset, data)
     return search_data
 
 
 class AsyncSearchModelBinding(object):
 
-    @bind('search')
+    @ bind('search')
     async def search(self, data, *args, **kwargs):
         await self.reflect(f'search', await async_search_data(self, data), *args, **kwargs)
 
@@ -50,7 +63,7 @@ class AsyncSearchModelBinding(object):
     def serialize_search_row(self, instance, data):
         return self.serialize_retrieve(instance, data)
 
-    @bind('search_suggestions')
+    @ bind('search_suggestions')
     async def search_suggestions(self, data, *args, **kwargs):
         query = data.get('query', '')
         await self.reflect(f'search_suggestions', dict(
